# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ComponentTemplate(Component):
    """A ComponentTemplate component.
Lazy loaded ComponentTemplate

@param {
	id,
} [props={}]
@return {*}

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'ComponentTemplate'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(ComponentTemplate, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AutoComplete(Component):
    """An AutoComplete component.
Lazy loaded Autocomplete

@param {
	id,
	autoselect,
	cssNamespace,
	defaultValue,
	displayMenu,
	minLength,
	name,
	placeholder,
	onConfirm,
	confirmOnBlur,
	showNoOptionsFound,
	showAllValues,
	required,
	tNoResults,
	tAssistiveHint,
	source,
	templates,
	dropdownArrow: dropdownArrowFactory,
	tStatusQueryTooShort,
	tStatusNoResults,
	tStatusSelectedOption,
	tStatusResults,
	style,
 errorMessage,
} [props={}]
@return {*}

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alwaysDisplayArrow (boolean; default True):
    alwaysDisplayArrow.

- ariaLabelledBy (string; optional):
    This is the ID for the label field.

- autoselect (boolean; default False):
    Should auto select.

- confirmOnBlur (boolean; default True):
    No Description.

- cssNamespace (string; default 'autocomplete'):
    cssNamespace.

- displayMenu (string; default 'inline'):
    No Description.

- dropdownArrow (boolean | number | string | dict | list; default DropdownArrowDown):
    React component for dropdown arrow.

- errorMessage (string; default 'Invalid value entered'):
    Error message to display when invalid input entered in dropdown.

- minLength (number; default 0):
    No Description.

- name (string; default 'input-autocomplete'):
    No Description.

- placeholder (string; default ''):
    No Description.

- required (boolean; default False):
    No Description.

- selectElement (boolean | number | string | dict | list; optional):
    Accessible element.

- showAllValues (boolean; default False):
    No Description.

- showNoOptionsFound (boolean; default True):
    No Description.

- source (boolean | number | string | dict | list; optional):
    No Description.

- style (boolean | number | string | dict | list; optional):
    Override the css style of the wrapper.

- tStatusNoResults (boolean | number | string | dict | list; optional):
    No Description.

- tStatusResults (boolean | number | string | dict | list; optional):
    No Description.

- templates (boolean | number | string | dict | list; optional):
    No Description.

- value (string; default ''):
    The value displayed in the input.

- wrapperRef (boolean | number | string | dict | list; optional):
    wrapperRef."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'AutoComplete'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, autoselect=Component.UNDEFINED, cssNamespace=Component.UNDEFINED, displayMenu=Component.UNDEFINED, minLength=Component.UNDEFINED, name=Component.UNDEFINED, placeholder=Component.UNDEFINED, onConfirm=Component.UNDEFINED, confirmOnBlur=Component.UNDEFINED, showNoOptionsFound=Component.UNDEFINED, showAllValues=Component.UNDEFINED, required=Component.UNDEFINED, tNoResults=Component.UNDEFINED, tAssistiveHint=Component.UNDEFINED, source=Component.UNDEFINED, templates=Component.UNDEFINED, tStatusQueryTooShort=Component.UNDEFINED, tStatusNoResults=Component.UNDEFINED, tStatusSelectedOption=Component.UNDEFINED, tStatusResults=Component.UNDEFINED, dropdownArrow=Component.UNDEFINED, selectElement=Component.UNDEFINED, value=Component.UNDEFINED, alwaysDisplayArrow=Component.UNDEFINED, wrapperRef=Component.UNDEFINED, style=Component.UNDEFINED, errorMessage=Component.UNDEFINED, ariaLabelledBy=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'alwaysDisplayArrow', 'ariaLabelledBy', 'autoselect', 'confirmOnBlur', 'cssNamespace', 'displayMenu', 'dropdownArrow', 'errorMessage', 'minLength', 'name', 'placeholder', 'required', 'selectElement', 'showAllValues', 'showNoOptionsFound', 'source', 'style', 'tStatusNoResults', 'tStatusResults', 'templates', 'value', 'wrapperRef']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'alwaysDisplayArrow', 'ariaLabelledBy', 'autoselect', 'confirmOnBlur', 'cssNamespace', 'displayMenu', 'dropdownArrow', 'errorMessage', 'minLength', 'name', 'placeholder', 'required', 'selectElement', 'showAllValues', 'showNoOptionsFound', 'source', 'style', 'tStatusNoResults', 'tStatusResults', 'templates', 'value', 'wrapperRef']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AutoComplete, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class status(Component):
    """A status component.
Display ststus

@export
@class Status
@extends {Component}

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- length (number; optional):
    length.

- minQueryLength (number; optional):
    min Query Length.

- queryLength (number; optional):
    Query Length.

- selectedOption (boolean | number | string | dict | list; optional):
    Selected option.

- selectedOptionIndex (number; optional):
    Selected Option Index."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'uk_gov_dash_components'
    _type = 'status'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, length=Component.UNDEFINED, minQueryLength=Component.UNDEFINED, queryLength=Component.UNDEFINED, selectedOption=Component.UNDEFINED, selectedOptionIndex=Component.UNDEFINED, tQueryTooShort=Component.UNDEFINED, tNoResults=Component.UNDEFINED, tSelectedOption=Component.UNDEFINED, tResults=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'length', 'minQueryLength', 'queryLength', 'selectedOption', 'selectedOptionIndex']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'length', 'minQueryLength', 'queryLength', 'selectedOption', 'selectedOptionIndex']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(status, self).__init__(**args)



from .Accordion import Accordion
from .AutoComplete import AutoComplete
from .CheckboxList import CheckboxList
from .ComponentTemplate import ComponentTemplate
from .Dropdown import Dropdown
from .ExpandableMenuItem import ExpandableMenuItem
from .dropdownArrowDown import dropdownArrowDown
from .status import status
from .ComboBox import ComboBox
from .ListBox import ListBox
from .Popover import Popover

__all__ = [
    "Accordion",
    "AutoComplete",
    "CheckboxList",
    "ComponentTemplate",
    "Dropdown",
    "ExpandableMenuItem",
    "dropdownArrowDown",
    "status",
    "ComboBox",
    "ListBox",
    "Popover"
]


from __future__ import print_function as _

import os as _os
import sys as _sys
import json

import dash as _dash

# noinspection PyUnresolvedReferences
from ._imports_ import *
from ._imports_ import __all__

if not hasattr(_dash, "__plotly_dash") and not hasattr(_dash, "development"):
    print(
        "Dash was not successfully imported. "
        "Make sure you don't have a file "
        'named \n"dash.py" in your current directory.',
        file=_sys.stderr,
    )
    _sys.exit(1)

_basepath = _os.path.dirname(__file__)
_filepath = _os.path.abspath(_os.path.join(_basepath, "package-info.json"))
with open(_filepath) as f:
    package = json.load(f)

package_name = package["name"].replace(" ", "_").replace("-", "_")
__version__ = package["version"]

_current_path = _os.path.dirname(_os.path.abspath(__file__))

_this_module = _sys.modules[__name__]

async_resources = [
    "UkGovDashComponents",
]

_js_dist = []

_js_dist.extend(
    [
        {
            "relative_package_path": "async-{}.js".format(async_resource),
            "external_url": ("https://unpkg.com/{0}@{2}" "/{1}/async-{3}.js").format(
                package_name, __name__, __version__, async_resource
            ),
            "namespace": package_name,
            "async": True,
        }
        for async_resource in async_resources
    ]
)

# TODO: Figure out if unpkg link works
_js_dist.extend(
    [
        {
            "relative_package_path": "async-{}.js.map".format(async_resource),
            "external_url": (
                "https://unpkg.com/{0}@{2}" "/{1}/async-{3}.js.map"
            ).format(package_name, __name__, __version__, async_resource),
            "namespace": package_name,
            "dynamic": True,
        }
        for async_resource in async_resources
    ]
)

_js_dist.extend(
    [
        {
            "relative_package_path": "uk_gov_dash_components.min.js",
            "namespace": package_name,
        },
        {
            "relative_package_path": "uk_gov_dash_components.min.js.map",
            "namespace": package_name,
            "dynamic": True,
        },
    ]
)

_css_dist = []


for _component in __all__:
    setattr(locals()[_component], "_js_dist", _js_dist)
    setattr(locals()[_component], "_css_dist", _css_dist)
